==> haskell-uri-encode-1.5.0.7-274-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-encode
version:              1.5.0.7
visibility:           public
id:                   uri-encode-1.5.0.7-Q3C4oLmmaL1P0p6PFZ2pg
key:                  uri-encode-1.5.0.7-Q3C4oLmmaL1P0p6PFZ2pg
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding
description:
    This package allows you to uri encode and uri decode
    Strings, Texts and ByteString values.

category:             Network, Web
abi:                  3e735544cc07e6cba1e95f5b35013ea7
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-encode
hs-libraries:         HSuri-encode-1.5.0.7-Q3C4oLmmaL1P0p6PFZ2pg
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-uri-2.6.4.2-37qi4fIAhTC8owHWseusWs text-2.0.2
    utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-encode-1.5.0.7-275-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-encode
version:              1.5.0.7
visibility:           public
id:                   uri-encode-1.5.0.7-FFv3Ntgvsv8JxOlwJaOGGp
key:                  uri-encode-1.5.0.7-FFv3Ntgvsv8JxOlwJaOGGp
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding
description:
    This package allows you to uri encode and uri decode
    Strings, Texts and ByteString values.

category:             Network, Web
abi:                  8fa72e79243385702a2866dbe26de62e
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-encode
hs-libraries:         HSuri-encode-1.5.0.7-FFv3Ntgvsv8JxOlwJaOGGp
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-uri-2.6.4.2-BUyFg1hFmM35dSD0y76h3W text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
